// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef AKONADINOTES_VERSION_H
#define AKONADINOTES_VERSION_H

#define AKONADINOTES_VERSION_STRING "6.2.3"
#define AKONADINOTES_VERSION_MAJOR 6
#define AKONADINOTES_VERSION_MINOR 2
#define AKONADINOTES_VERSION_PATCH 3
#define AKONADINOTES_VERSION ((6<<16)|(2<<8)|(3))

#endif
